/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/*!
@file cameraCalibrator.cpp
@ingroup OpenCVExamplePrograms
@brief Obtains intrinsic camera matrix and distortion coefficients for a camera.

This example is based on the example 11-1 from the book:

@code
Learning OpenCV: Computer Vision with the OpenCV Library
     by Gary Bradski and Adrian Kaehler
     Published by O'Reilly Media, October 3, 2008
@endcode

It uses the chessboard template image <i>OpenCV_Chessboard.png</i> attacked to the source code to obtain the camera calibration parameters.

@section Usage
Once compiled, the program should be used with this command line:
\code
	./cameraCalibrator --URL=<video source>
\endcode

10 images containing the chessboard must be captured using the <i>Grab chessboard</i> button of the graphical user interface. Then the application will calibrate the intrinsic camera parameters when the button <i>Calibrate</i> is pressed.

@author PARP Research Group. University of Murcia, Spain.
*/
#include <iostream>
#include <QVMatrix>
#include <QVApplication>
#include <QVImageCanvas>
#include <QVMPlayerCameraWorker>
#include <QVDefaultGUI>

#ifndef DOXYGEN_IGNORE_THIS
#ifdef OPENCV
#include <cv.h>
#include <highgui.h>

/* *************** License:**************************
   Oct. 3, 2008
   Right to use this code in any way you want without warrenty, support or any guarentee of it working.

   BOOK: It would be nice if you cited it:
   Learning OpenCV: Computer Vision with the OpenCV Library
     by Gary Bradski and Adrian Kaehler
     Published by O'Reilly Media, October 3, 2008
 
   AVAILABLE AT: 
     http://www.amazon.com/Learning-OpenCV-Computer-Vision-Library/dp/0596516134
     Or: http://oreilly.com/catalog/9780596516130/
     ISBN-10: 0596516134 or: ISBN-13: 978-0596516130    

   OTHER OPENCV SITES:
   * The source code is on sourceforge at:
     http://sourceforge.net/projects/opencvlibrary/
   * The OpenCV wiki page (As of Oct 1, 2008 this is down for changing over servers, but should come back):
     http://opencvlibrary.sourceforge.net/
   * An active user group is at:
     http://tech.groups.yahoo.com/group/OpenCV/
   * The minutes of weekly OpenCV development meetings are at:
     http://pr.willowgarage.com/wiki/OpenCV
   ************************************************** */

/*void help()
	{
	std::cout << "\n\n"
	" Calling convention:\n"
	" ./cameraCalibratorOpenCV  <board_w>  <board_h>  <number_of_boards>  <skip_frames>\n"
	"\n"
	"   WHERE:\n"
	"     board_w, board_h   -- are the number of corners along the row and columns respectively\n"
	"     number_of_boards   -- are the number of chessboard views to collect before calibration\n"
	"     skip_frames        -- are the number of frames to skip before trying to collect another\n"
	"                           good chessboard.  This allows you time to move the chessboard.  \n"
	"                           Move it to many different locations and angles so that calibration \n"
	"                           space will be well covered. \n"
	"\n"
	" Hit ‘p’ to pause/unpause, ESC to quit\n"
	"\n";
	}*/

class CameraCalibratorWorker: public QVWorker
	{
	private:
		QVImage<uChar, 3> actualImage;

		const int board_w, board_h, n_boards, board_dt, board_n;
		const CvSize board_sz;
		CvSize image_sz;

		CvMat* image_points;
		CvMat* object_points;
		CvMat* point_counts;
		
		CvPoint2D32f* corners;
		int successes;//, corner_count, step;//, frame;

	public:
		CameraCalibratorWorker(QString name): QVWorker(name),
			board_w(6), board_h(9), n_boards(10), board_dt(25), board_n(board_w * board_h),
			board_sz(cvSize( board_w, board_h )), image_points(cvCreateMat(n_boards*board_n,2,CV_32FC1)),
			object_points(cvCreateMat(n_boards*board_n,3,CV_32FC1)), point_counts(cvCreateMat(n_boards,1,CV_32SC1)),
			corners(new CvPoint2D32f[ board_n ]), successes(0)//, frame(0)
			{
			addProperty< QVImage<uChar,3> >("Input image", inputFlag|outputFlag);
			addTrigger("Grab chessboard");
			addTrigger("Calibrate");
			}

		void processTrigger(const QString triggerName)
			{
			if (triggerName == "Grab chessboard")
				{
				if (successes >= n_boards) 
					{
					std::cout << "Already got "<< n_boards << " boards" << std::endl;
					return;
					}

				std::cout << "Capturing image" << std::endl;
				IplImage *image = actualImage;
				IplImage *gray_image = cvCreateImage(cvGetSize(image), 8, 1); //subpixel
	
				image_sz = cvGetSize(image);

				int corner_count, found = cvFindChessboardCorners(
									image, board_sz, corners, &corner_count,
									CV_CALIB_CB_ADAPTIVE_THRESH | CV_CALIB_CB_FILTER_QUADS);
				
				//Get Subpixel accuracy on those corners
				cvCvtColor(image, gray_image, CV_BGR2GRAY);
				cvFindCornerSubPix(	gray_image, corners, corner_count, cvSize(11,11),cvSize(-1,-1),
							cvTermCriteria(CV_TERMCRIT_EPS+CV_TERMCRIT_ITER, 30, 0.1));
	
				if(corner_count == board_n)
					{
					//cvShowImage( "Calibration", image ); //show in color if we did collect the image
					int step = successes*board_n;
					for( int i=step, j=0; j<board_n; ++i,++j )
						{
						CV_MAT_ELEM(*image_points, float,i,0) = corners[j].x;
						CV_MAT_ELEM(*image_points, float,i,1) = corners[j].y;
						CV_MAT_ELEM(*object_points,float,i,0) = j/board_w;
						CV_MAT_ELEM(*object_points,float,i,1) = j%board_w;
						CV_MAT_ELEM(*object_points,float,i,2) = 0.0f;
						}
					CV_MAT_ELEM(*point_counts, int,successes,0) = board_n;    
					successes++;
					std::cout << "Got board # " << successes << " of " << n_boards << " required" << std::endl;
					}
				cvReleaseImage(&image);
				cvReleaseImage(&gray_image);
				}
			else if (triggerName == "Calibrate")
				{
				if (successes < n_boards) 
					{
					std::cout << "Not enough boards" << std::endl;
					return;
					}
				std::cout << "Proceeding to camera calibration." << std::endl;
				CvMat* object_points2  = cvCreateMat(successes*board_n,3,CV_32FC1);
				CvMat* image_points2   = cvCreateMat(successes*board_n,2,CV_32FC1);
				CvMat* point_counts2   = cvCreateMat(successes,1,CV_32SC1);
			
				//TRANSFER THE POINTS INTO THE CORRECT SIZE MATRICES
				for(int i = 0; i<successes*board_n; ++i)
					{
					CV_MAT_ELEM( *image_points2, float, i, 0) = CV_MAT_ELEM( *image_points, float, i, 0);
					CV_MAT_ELEM( *image_points2, float,i,1) = CV_MAT_ELEM( *image_points, float, i, 1);
					CV_MAT_ELEM(*object_points2, float, i, 0) = CV_MAT_ELEM( *object_points, float, i, 0) ;
					CV_MAT_ELEM( *object_points2, float, i, 1) = CV_MAT_ELEM( *object_points, float, i, 1) ;
					CV_MAT_ELEM( *object_points2, float, i, 2) = CV_MAT_ELEM( *object_points, float, i, 2) ;
					}
			
				for(int i=0; i<successes; ++i)
					//These are all the same number
					CV_MAT_ELEM( *point_counts2, int, i, 0) = CV_MAT_ELEM( *point_counts, int, i, 0);
	
				CvMat* intrinsic_matrix  = cvCreateMat(3,3,CV_32FC1);
				CvMat* distortion_coeffs = cvCreateMat(4,1,CV_32FC1);
			
				CV_MAT_ELEM( *intrinsic_matrix, float, 0, 0 ) = 1.0f;
				CV_MAT_ELEM( *intrinsic_matrix, float, 1, 1 ) = 1.0f;
				
				cvCalibrateCamera2(object_points2, image_points2, point_counts2,  image_sz, intrinsic_matrix, distortion_coeffs, NULL, NULL,0);
				
				std::cout << "Intrinsic Matrix K = " << std::endl << QVMatrix(intrinsic_matrix) << std::endl;
				std::cout << "Distortion coefficents = " << std::endl << QVMatrix(distortion_coeffs) << std::endl;

				cvReleaseMat(&object_points2);
				cvReleaseMat(&image_points2);
				cvReleaseMat(&point_counts2);
				cvReleaseMat(&intrinsic_matrix);
				cvReleaseMat(&distortion_coeffs);
				}
			}

		void iterate()
			{
			actualImage = getPropertyValue<QVImage<uChar, 3> >("Input image");
			}
	};

#include <QVVector>
#include <QVMatrix>
int main(int argc, char *argv[])
	{
	QVApplication app(argc, argv, "Example program for QVision library. Displays the contents of a video source.");

	QVMPlayerCameraWorker camera("Video");

	CameraCalibratorWorker player("Video player");
	camera.linkProperty(&player,"Input image");

	QVDefaultGUI interface;

	QVImageCanvas imageCanvas("Output image");
	player.linkProperty("Input image", imageCanvas);

	return app.exec();
	}

/*int main(int argc, char* argv[])
	{
	exit(0);
	CvCapture* capture;
	
	if(argc != 5)
		{
		std::cout << std::endl << "ERROR: Wrong number of input parameters" << std::endl;
		help();
		return -1;
		}

	const int	board_w  = 6,
			board_h  = 9,
			n_boards = 10,
			board_dt = 25,
			board_n  = board_w * board_h;

	CvSize board_sz = cvSize( board_w, board_h );

	////////////////////
	capture = cvCreateCameraCapture( 0 );
	if(!capture)
		{
		std::cout << std::endl << "Couldn't open the camera" << std::endl;
		help();
		return -1;
		}
	
	cvNamedWindow("Calibration");
	cvNamedWindow("Raw Video");
	////////////////////
	
	//ALLOCATE STORAGE
	CvMat* image_points      = cvCreateMat(n_boards*board_n,2,CV_32FC1);
	CvMat* object_points     = cvCreateMat(n_boards*board_n,3,CV_32FC1);
	CvMat* point_counts      = cvCreateMat(n_boards,1,CV_32SC1);
	
	CvPoint2D32f* corners = new CvPoint2D32f[ board_n ];
	int corner_count, successes = 0, step, frame = 0;
	IplImage *image = cvQueryFrame( capture );
	IplImage *gray_image = cvCreateImage(cvGetSize(image), 8, 1); //subpixel
	
	// CAPTURE CORNER VIEWS LOOP UNTIL WE’VE GOT n_boards 
	// SUCCESSFUL CAPTURES (ALL CORNERS ON THE BOARD ARE FOUND)
	//
	help();

	while(successes < n_boards)
		{
		//Skip every board_dt frames to allow user to move chessboard
		if((frame++ % board_dt) == 0)
			{
			//Find chessboard corners:
			int found = cvFindChessboardCorners(	image, board_sz, corners, &corner_count,
								CV_CALIB_CB_ADAPTIVE_THRESH | CV_CALIB_CB_FILTER_QUADS);
			
			//Get Subpixel accuracy on those corners
			cvCvtColor(image, gray_image, CV_BGR2GRAY);
			cvFindCornerSubPix(	gray_image, corners, corner_count, cvSize(11,11),cvSize(-1,-1),
						cvTermCriteria(CV_TERMCRIT_EPS+CV_TERMCRIT_ITER, 30, 0.1));
			
			//Draw it
			cvDrawChessboardCorners(image, board_sz, corners, corner_count, found);
			
			// If we got a good board, add it to our data
			if(corner_count == board_n)
				{
				cvShowImage( "Calibration", image ); //show in color if we did collect the image
				step = successes*board_n;
				for( int i=step, j=0; j<board_n; ++i,++j )
					{
					CV_MAT_ELEM(*image_points, float,i,0) = corners[j].x;
					CV_MAT_ELEM(*image_points, float,i,1) = corners[j].y;
					CV_MAT_ELEM(*object_points,float,i,0) = j/board_w;
					CV_MAT_ELEM(*object_points,float,i,1) = j%board_w;
					CV_MAT_ELEM(*object_points,float,i,2) = 0.0f;
					}
				CV_MAT_ELEM(*point_counts, int,successes,0) = board_n;    
				successes++;
				std::cout << "Collected our " << successes << " of " << n_boards << " needed chessboard images" << std::endl;
				}
			else
				cvShowImage("Calibration", gray_image); //Show Gray if we didn't collect the image
			} //end skip board_dt between chessboard capture
		
		//Handle pause/unpause and ESC
		int c = cvWaitKey(15);
		if(c == 'p')
			{  
			c = 0;
			while(c != 'p' && c != 27)
				c = cvWaitKey(250);
			}
	
		if(c == 27)
			return 0;
	
		image = cvQueryFrame( capture ); //Get next image
		cvShowImage("Raw Video", image);
		} //END COLLECTION WHILE LOOP.

	cvDestroyWindow("Calibration");
	std::cout << "\n\n*** CALLIBRATING THE CAMERA..." << std::endl;

	//ALLOCATE MATRICES ACCORDING TO HOW MANY CHESSBOARDS FOUND
	CvMat* object_points2  = cvCreateMat(successes*board_n,3,CV_32FC1);
	CvMat* image_points2   = cvCreateMat(successes*board_n,2,CV_32FC1);
	CvMat* point_counts2   = cvCreateMat(successes,1,CV_32SC1);

	//TRANSFER THE POINTS INTO THE CORRECT SIZE MATRICES
	for(int i = 0; i<successes*board_n; ++i)
		{
		CV_MAT_ELEM( *image_points2, float, i, 0) = CV_MAT_ELEM( *image_points, float, i, 0);
		CV_MAT_ELEM( *image_points2, float,i,1) = CV_MAT_ELEM( *image_points, float, i, 1);
		CV_MAT_ELEM(*object_points2, float, i, 0) = CV_MAT_ELEM( *object_points, float, i, 0) ;
		CV_MAT_ELEM( *object_points2, float, i, 1) = CV_MAT_ELEM( *object_points, float, i, 1) ;
		CV_MAT_ELEM( *object_points2, float, i, 2) = CV_MAT_ELEM( *object_points, float, i, 2) ;
		}

	for(int i=0; i<successes; ++i)
		//These are all the same number
		CV_MAT_ELEM( *point_counts2, int, i, 0) = CV_MAT_ELEM( *point_counts, int, i, 0);

	cvReleaseMat(&object_points);
	cvReleaseMat(&image_points);
	cvReleaseMat(&point_counts);
	
	// At this point we have all of the chessboard corners we need.
	// Initialize the intrinsic matrix such that the two focal
	// lengths have a ratio of 1.0
	CvMat* intrinsic_matrix  = cvCreateMat(3,3,CV_32FC1);
	CvMat* distortion_coeffs = cvCreateMat(4,1,CV_32FC1);

	CV_MAT_ELEM( *intrinsic_matrix, float, 0, 0 ) = 1.0f;
	CV_MAT_ELEM( *intrinsic_matrix, float, 1, 1 ) = 1.0f;
	
	//CALIBRATE THE CAMERA!
	cvCalibrateCamera2(object_points2, image_points2, point_counts2,  cvGetSize( image ), intrinsic_matrix, distortion_coeffs, NULL, NULL,0);
	
	// SAVE THE INTRINSICS AND DISTORTIONS
	std::cout << " *** DONE!" << std::endl << std::endl << "Storing Intrinsics.xml and Distortions.xml files" << std::endl << std::endl;

	//std::cout << "Intrinsic Matrix K = " << std::endl << CvMatToQVMatrix(intrinsic_matrix) << std::endl;
	std::cout << "Intrinsic Matrix K = " << std::endl << QVMatrix(intrinsic_matrix) << std::endl;
	//std::cout << "Distortion coefficents = " << std::endl << CvMatToQVMatrix(distortion_coeffs) << std::endl;
	std::cout << "Distortion coefficents = " << std::endl << QVMatrix(distortion_coeffs) << std::endl;
	
	return 0;
	}*/
#else	// not OPENCV
int main(int argc, char* argv[])
	{
	std::cout << "ERROR: OpenCV compatibility was not activated in QVision compilation." << std::endl;
	return -1;
	}
#endif	// OPENCV
#endif	// DOXYGEN_IGNORE_THIS

