/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvcameraworker.cpp
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <QTimer>

#include <QVImage>
#include <qvio/qvcameraworker.h>
#include <qvip/qvipp/qvipp.h>

#define DEFAULT_IMAGE_SIZE 128

QVCameraWorker::QVCameraWorker(QString name): QVWorker(name)
	{
	// Input properties:
	addProperty<bool>("NoLoop", inputFlag, FALSE,"If the camera should be opened in no loop mode");
	addProperty<QString>("URL", inputFlag, QString(""),"URL of the video source to read");
	addProperty<int>("Cols", inputFlag, 0, "Suggested number of columns of the video");
	addProperty<int>("Rows", inputFlag, 0, "Suggested number of rows of the video");
	// RealTime property is also input (and as such can be initialized using the command line), but invisible to the GUI
	// (because once the camera has been linked, it cannot be relinked changing its synchronism):
	addProperty<bool>("RealTime", inputFlag|guiInvisible, FALSE, "If the camera should be opened in real time mode");

	// Output integer and boolean properties:
	addProperty<bool>("Opened", outputFlag, FALSE, "If the camera is correctly opened and working");
	addProperty<int>("FPS", outputFlag, 0, "FPS of the video");
	addProperty<int>("Frames", outputFlag, 0, "Number of read frames");
	addProperty<int>("ColsR", outputFlag, 0, "Actual number of columns of the video");
	addProperty<int>("RowsR", outputFlag, 0, "Actual number of rows of the video");
	addProperty<double>("Pos", outputFlag, 0.0, "Current time position of the video");
	addProperty<double>("Length", outputFlag, 0.0, "Length of the video (0.0 if not available)");

	// Output image properties:
	addProperty< QVImage<uChar,3> >("RGB image", outputFlag, QVImage<uChar,3>(), "Last grabbed RGB image");
	addProperty< QVImage<uChar,1> >("Y channel image",outputFlag, QVImage<uChar,1>(), "Last grabbed Y channel image");
	addProperty< QVImage<uChar,1> >("U channel image",outputFlag, QVImage<uChar,1>(), "Last grabbed U channel image");
	addProperty< QVImage<uChar,1> >("V channel image",outputFlag, QVImage<uChar,1>(), "Last grabbed V channel image");

	// Initial images (only useful if first open fails, for a default set of images to be available...)
	imageY = QVImage<uChar>(DEFAULT_IMAGE_SIZE,DEFAULT_IMAGE_SIZE,DEFAULT_IMAGE_SIZE);
	imageU = QVImage<uChar>(DEFAULT_IMAGE_SIZE/2,DEFAULT_IMAGE_SIZE/2,DEFAULT_IMAGE_SIZE/2);
	imageV = QVImage<uChar>(DEFAULT_IMAGE_SIZE/2,DEFAULT_IMAGE_SIZE/2,DEFAULT_IMAGE_SIZE/2);
	Set(128,imageY);
	Set(128,imageU);
	Set(128,imageV);
	setPropertyValue< QVImage<uChar, 1> >("Y channel image", imageY);
	setPropertyValue< QVImage<uChar, 1> >("U channel image", imageU);
	setPropertyValue< QVImage<uChar, 1> >("V channel image", imageV);
	QVImage<uChar, 3> imageRGB(DEFAULT_IMAGE_SIZE,DEFAULT_IMAGE_SIZE);
	YUV420ToRGB(imageY, imageU, imageV, imageRGB);
	setPropertyValue< QVImage<uChar, 3> >("RGB image", imageRGB);

	// Flag needed later to flush out pending images in real time cameras when resetting the camera:
	flush_pending_images = FALSE;

	}

QVCameraWorker::~QVCameraWorker()
	{
	// closeCam() must be called in the destructor of the derived class, because it is virtual, and thus can't be
	// called by this base class destructor.
	}

static inline int iRoundUp(int a, int b) {
  return (a % b == 0) ? a : b*(a / b + 1) ;
}

void QVCameraWorker::tryOpeningCam()
{
	// We open the camera with the specified input properties, and update output properties accordingly:
	int cols, rows, fps;

	// Read current input properties:
	realTime = getPropertyValue<bool>("RealTime");
	noLoop = getPropertyValue<bool>("NoLoop");
	urlName = getPropertyValue<QString>("URL");
	cols =  getPropertyValue<int>("Cols");
	rows =  getPropertyValue<int>("Rows");

	// Virtual call; urlName is input parameter; cols and rows are input/output; fps is output.
	if(this->openCam(urlName,cols,rows,fps)) 
		{
		setPropertyValue<bool>("Opened",TRUE);
		setPropertyValue<int>("ColsR",cols);
		setPropertyValue<int>("RowsR",rows);
		setPropertyValue<int>("FPS",fps);
		setPropertyValue<int>("Frames",0);
		setPropertyValue<double>("Pos",this->currentPos());
		setPropertyValue<double>("Length",this->lengthOfVideo());

		imageY = QVImage<uChar>(cols, rows, iRoundUp(cols,8));
		imageU = QVImage<uChar>(cols/2, rows/2, iRoundUp(cols/2,8));
		imageV = QVImage<uChar>(cols/2, rows/2, iRoundUp(cols/2,8));
		setPropertyValue< QVImage<uChar, 1> >("Y channel image", imageY);
		setPropertyValue< QVImage<uChar, 1> >("U channel image", imageU);
		setPropertyValue< QVImage<uChar, 1> >("V channel image", imageV);
		setPropertyValue< QVImage<uChar, 3> >("RGB image", QVImage<uChar,3>(cols, rows, iRoundUp(3*cols,8)));

		// If the camera is in real time mode, a single shot timer will do the grabbing job (this timer will
		// always be relaunched after each grab()). Otherwise, the QVCameraWorker::iterate() will simply call 
		// explicitly the grabFrame slot.
		if (realTime)
             		QTimer::singleShot(0, this, SLOT(grabFrame()));  // Schedule first grabFrame()

		// Once opened, the worker is ready to run (useful when reopening stopped cameras):
		unPause();

		// Trick to block too fast consumer workers, if in real time:
		if (realTime)
			connectOrDisconnectLinkedWorkers(TRUE);

		emit opened();
		}
	else	// If something fails when opening, we reset using resetCameraWorker():
		resetCameraWorker();
}

void QVCameraWorker::connectOrDisconnectLinkedWorkers(bool connect_disconnect)
	{
	QList<QVPropertyContainer*> list_linked_qvps = getDestinyContainers("RGB image");
	list_linked_qvps << getDestinyContainers("Y channel image");
	list_linked_qvps << getDestinyContainers("U channel image");
	list_linked_qvps << getDestinyContainers("V channel image");
	QSet<QVPropertyContainer*> set_linked_qvps = list_linked_qvps.toSet();
	QVWorker *worker;
	foreach (QVPropertyContainer *qvp, set_linked_qvps)
		if((worker = dynamic_cast<QVWorker*>(qvp)) != NULL)
			if(connect_disconnect)
				connect(worker,SIGNAL(endIteration(uint,int)),this,SLOT(nothing()),Qt::BlockingQueuedConnection);
			else
				disconnect(worker,SIGNAL(endIteration(uint,int)),this,SLOT(nothing()));
	}

void QVCameraWorker::resetCameraWorker()
	{
	// Disconnect consumer workers, if in real time (trick for fast consumer workers):
	if(realTime)
		connectOrDisconnectLinkedWorkers(FALSE);

	// Flush any possible timer event pending:
	flush_pending_images = TRUE;
	while(qApp->hasPendingEvents ()) qApp->processEvents();
	flush_pending_images = FALSE;

	// Close camera ...
	this->closeCam(); // Virtual call.

	// ... reset output properties (except images and RowsR/ColsR, that are left untouched), ...
	setPropertyValue<bool>("Opened",FALSE);
	setPropertyValue<int>("FPS",0);
	setPropertyValue<int>("Frames",0);
	setPropertyValue<double>("Pos",0.0);
	setPropertyValue<double>("Length",0.0);

	// ...and stop worker:
	stop();

	emit closed();
	}


bool QVCameraWorker::linkProperty(QVPropertyContainer *destinyContainer, QString destinyPropertyName)
	{
	// Asynchronous links for real time cameras, synchronous for non real time:
	LinkType linkType = getPropertyValue<bool>("RealTime") ? AsynchronousLink : SynchronousLink;

	// Link the destination image property, depending on the number of channels.
	if (destinyContainer->isType< QVImage<uChar, 3> >(destinyPropertyName))
		return QVWorker::linkProperty("RGB image", destinyContainer, destinyPropertyName, linkType);
	else if (destinyContainer->isType< QVImage<uChar, 1> >(destinyPropertyName))
		return QVWorker::linkProperty("Y channel image", destinyContainer, destinyPropertyName, linkType);
	else
		{
		qWarning() << "QVCameraWorker::link(): error, can't link property " << qPrintable(destinyPropertyName) << ".";
		return false;
		}
	}

bool QVCameraWorker::linkProperty(QVPropertyContainer *destinyContainer, QString destinyPropertyName1, QString destinyPropertyName2, QString destinyPropertyName3)
	{
	// Asynchronous links for real time cameras, synchronous for non real time:
	LinkType linkType = getPropertyValue<bool>("RealTime") ? AsynchronousLink : SynchronousLink;

	bool ok = TRUE;

	// Link the destination image properties (must be one channel each)
	if (destinyContainer->isType< QVImage<uChar, 1> >(destinyPropertyName1))
		if(not QVWorker::linkProperty("Y channel image", destinyContainer, destinyPropertyName1, linkType))
			{
			ok = FALSE;
			qWarning() << "QVCameraWorker::linkProperty(): error, can't link Y property " << qPrintable(destinyPropertyName1) ;
			}
	if (destinyContainer->isType< QVImage<uChar, 1> >(destinyPropertyName2))
		if(not QVWorker::linkProperty("U channel image", destinyContainer, destinyPropertyName2, linkType))
			{
			ok = FALSE;
			qWarning() << "QVCameraWorker::linkProperty(): error, can't link U property " << qPrintable(destinyPropertyName2) ;
			}
	if (destinyContainer->isType< QVImage<uChar, 1> >(destinyPropertyName3))
		if(not QVWorker::linkProperty("V channel image", destinyContainer, destinyPropertyName3, linkType))
			{
			ok = FALSE;
			qWarning() << "QVCameraWorker::linkProperty(): error, can't link V property " << qPrintable(destinyPropertyName3) ;
			}

	return ok;
	}

void QVCameraWorker::grabFrame()
	{
	// Virtual call; imageY, imageU and imageV are output parameters.
	if(this->grab(imageY,imageU,imageV))
		{
		setPropertyValue<int>("Frames",getPropertyValue<int>("Frames")+1);
		setPropertyValue<double>("Pos",this->currentPos());
		// Needed here because mplayer does not know the length of the video until it has played a few frames:
		setPropertyValue<double>("Length",this->lengthOfVideo()); 

		static QTime t;
         	if(getPropertyValue<int>("Frames")==1)
			t.start();
		else
			{
			int ms = t.elapsed();
			if(ms>0) setPropertyValue<int>("FPS",1000/ms);
			t.restart();
			}

		if(realTime) writeOutputProperties();

		emit grabbed();

		// Post following timer event to schedule next grabbing (except if we are flushing images out for closing).
		if(realTime and not flush_pending_images)
			QTimer::singleShot(0, this, SLOT(grabFrame()));
		}
	else
		resetCameraWorker();
	}

void QVCameraWorker::iterate()
	{
	// Try opening camera if first iteration (performed here, instead of the constructor, to assure 
	// that openCam() is executed always in this thread.
	if(getIteration()==0)
		tryOpeningCam();

	// Needed for not try to grab from closed (stoped) cameras:
	if(isStoped()) return; 

	// If the camera is in real time mode, the timer should have called the slot for us, so we do not have to do it
	// explicitly. Otherwise, we call grabFrame();
	if (not realTime)
		grabFrame();

	setPropertyValue< QVImage<uChar, 1> >("Y channel image", imageY);
	setPropertyValue< QVImage<uChar, 1> >("U channel image", imageU);
	setPropertyValue< QVImage<uChar, 1> >("V channel image", imageV);

	if (isLinkedOutput("RGB image"))
		{
		QVImage<uChar, 3> imageRGB(imageY.getCols(),imageY.getRows());
		YUV420ToRGB(imageY, imageU, imageV, imageRGB);
		setPropertyValue< QVImage<uChar, 3> >("RGB image", imageRGB);
		}

	}

void QVCameraWorker::reopen()
	{
	// Do not try to reopen again if in the middle of a reopening process (could happen if the user presses the
	// "Reopen" camera widget button several times very quickly). This condition avoids it:
	if(flush_pending_images) return;

	// When reopening, we must reset the camera worker ...
	resetCameraWorker();
	// ... and open the camera again using the new input properties.
	readInputProperties();
	tryOpeningCam();
	}
