/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file qvippworkers.h
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <ipp.h>

#include <QMap>
#include <QSize>
#include <QPoint>
#include <QVImage>
#include <QVWorker>

#include <qvdefines.h>
#include <qvipp.h>
#include <qvip/qvipp/qvippfunctions.h>

#ifndef QVIPPWORKERS_H
#define QVIPPWORKERS_H

/*!
@brief Provides a full list of the names of all IPP workers

@returns a list of QString objects, corresponding to the names of the IPP workers
@see newQVIPPWorker
@ingroup qvippworkers
*/
const QMap<QString, QString> getQVIPPWorkersNames();

/*!
@brief Creates an IPP worker object, given its class name

This function can be used as a worker object factory.
Given the class name of an IPP worker included in the QVision framework, this function returns a pointer to a newly created worker of that type.

Any QVision application can dynamically obtain the full list of class names of IPP workers included in the framework with the function @ref getQVIPPWorkersNames.

@param type name of the type of the worker
@param name name which will be asigned to the new worker object
@returns a pointer to a new worker object, or NULL if no ipp worker class exists in the QVision
@ingroup qvippworkers
*/
QVPropertyContainer *newQVIPPWorker(QString type, QString name);

/*!
@brief Converts pixel values of an image from one bit depth to another

This is the QVision processing block for the IPP function <b>ippiConvert_8u32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVConvert_uCharsFloatC1Worker: public QVWorker
	{
	public:
		QVConvert_uCharsFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Converts pixel values of an image from one bit depth to another

This is the QVision processing block for the IPP function <b>ippiConvert_8u32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVConvert_uCharsFloatC3Worker: public QVWorker
	{
	public:
		QVConvert_uCharsFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Converts pixel values of an image from one bit depth to another

This is the QVision processing block for the IPP function <b>ippiConvert_32f8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param roundMode	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVConvert_sFloatuCharC1Worker: public QVWorker
	{
	public:
		QVConvert_sFloatuCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Converts pixel values of an image from one bit depth to another

This is the QVision processing block for the IPP function <b>ippiConvert_32f8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param roundMode	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVConvert_sFloatuCharC3Worker: public QVWorker
	{
	public:
		QVConvert_sFloatuCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Add image to accumulator

This is the QVision processing block for the IPP function <b>ippiAdd_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVAdd_uCharC1Worker: public QVWorker
	{
	public:
		QVAdd_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Add image to accumulator

This is the QVision processing block for the IPP function <b>ippiAdd_8u_C3RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVAdd_uCharC3Worker: public QVWorker
	{
	public:
		QVAdd_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Add image to accumulator

This is the QVision processing block for the IPP function <b>ippiAdd_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAdd_sFloatC1Worker: public QVWorker
	{
	public:
		QVAdd_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Add image to accumulator

This is the QVision processing block for the IPP function <b>ippiAdd_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAdd_sFloatC3Worker: public QVWorker
	{
	public:
		QVAdd_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiAddC_8u_C1RSfs

This is the QVision processing block for the IPP function <b>ippiAddC_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVAddC_uCharC1Worker: public QVWorker
	{
	public:
		QVAddC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiAddC_32f_C1R

This is the QVision processing block for the IPP function <b>ippiAddC_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAddC_sFloatC1Worker: public QVWorker
	{
	public:
		QVAddC_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of two source images and places the results in a destination image

This is the QVision processing block for the IPP function <b>ippiMul_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVMul_uCharC1Worker: public QVWorker
	{
	public:
		QVMul_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of two source images and places the results in a destination image

This is the QVision processing block for the IPP function <b>ippiMul_8u_C3RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVMul_uCharC3Worker: public QVWorker
	{
	public:
		QVMul_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of two source images and places the results in a destination image

This is the QVision processing block for the IPP function <b>ippiMul_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVMul_sFloatC3Worker: public QVWorker
	{
	public:
		QVMul_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of two source images and places the results in a destination image

This is the QVision processing block for the IPP function <b>ippiMul_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVMul_sFloatC1Worker: public QVWorker
	{
	public:
		QVMul_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of an image and a constant, and places the results in the same image

This is the QVision processing block for the IPP function <b>ippiMulC_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVMulC_uCharC1Worker: public QVWorker
	{
	public:
		QVMulC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Adds, subtracts, or multiplies pixel values of an image and a constant, and places the results in the same image

This is the QVision processing block for the IPP function <b>ippiMulC_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVMulC_sFloatC1Worker: public QVWorker
	{
	public:
		QVMulC_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiMulScale_8u_C1R

This is the QVision processing block for the IPP function <b>ippiMulScale_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVMulScale_uCharC1Worker: public QVWorker
	{
	public:
		QVMulScale_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiMulScale_8u_C3R

This is the QVision processing block for the IPP function <b>ippiMulScale_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVMulScale_uCharC3Worker: public QVWorker
	{
	public:
		QVMulScale_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSub_8u_C1RSfs

This is the QVision processing block for the IPP function <b>ippiSub_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVSub_uCharC1Worker: public QVWorker
	{
	public:
		QVSub_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSub_8u_C3RSfs

This is the QVision processing block for the IPP function <b>ippiSub_8u_C3RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVSub_uCharC3Worker: public QVWorker
	{
	public:
		QVSub_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSub_32f_C1R

This is the QVision processing block for the IPP function <b>ippiSub_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVSub_sFloatC1Worker: public QVWorker
	{
	public:
		QVSub_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSub_32f_C3R

This is the QVision processing block for the IPP function <b>ippiSub_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVSub_sFloatC3Worker: public QVWorker
	{
	public:
		QVSub_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSubC_8u_C1RSfs

This is the QVision processing block for the IPP function <b>ippiSubC_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVSubC_uCharC1Worker: public QVWorker
	{
	public:
		QVSubC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiSubC_32f_C1R

This is the QVision processing block for the IPP function <b>ippiSubC_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVSubC_sFloatC1Worker: public QVWorker
	{
	public:
		QVSubC_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of an image by pixel values of another image and places the scaled results in the dividend source image

This is the QVision processing block for the IPP function <b>ippiDiv_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVDiv_uCharC1Worker: public QVWorker
	{
	public:
		QVDiv_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of an image by pixel values of another image and places the scaled results in the dividend source image

This is the QVision processing block for the IPP function <b>ippiDiv_8u_C3RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVDiv_uCharC3Worker: public QVWorker
	{
	public:
		QVDiv_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of an image by pixel values of another image and places the scaled results in the dividend source image

This is the QVision processing block for the IPP function <b>ippiDiv_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVDiv_sFloatC3Worker: public QVWorker
	{
	public:
		QVDiv_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of an image by pixel values of another image and places the scaled results in the dividend source image

This is the QVision processing block for the IPP function <b>ippiDiv_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVDiv_sFloatC1Worker: public QVWorker
	{
	public:
		QVDiv_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of a source image by a constant and places the scaled results in a destination image

This is the QVision processing block for the IPP function <b>ippiDivC_8u_C1RSfs</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param scaleFactor	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVDivC_uCharC1Worker: public QVWorker
	{
	public:
		QVDivC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Divides pixel values of a source image by a constant and places the scaled results in a destination image

This is the QVision processing block for the IPP function <b>ippiDivC_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVDivC_sFloatC1Worker: public QVWorker
	{
	public:
		QVDivC_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes absolute value of each pixel of a source image and places results in the destination image; for in-place flavors - in the same source image

This is the QVision processing block for the IPP function <b>ippiAbs_16s_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAbs_sShortC1Worker: public QVWorker
	{
	public:
		QVAbs_sShortC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes absolute value of each pixel of a source image and places results in the destination image; for in-place flavors - in the same source image

This is the QVision processing block for the IPP function <b>ippiAbs_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAbs_sFloatC1Worker: public QVWorker
	{
	public:
		QVAbs_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Calculate absolute difference between corresponding pixels of the two images or between image pixels and scalar

This is the QVision processing block for the IPP function <b>ippiAbsDiff_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAbsDiff_uCharC1Worker: public QVWorker
	{
	public:
		QVAbsDiff_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Calculate absolute difference between corresponding pixels of the two images or between image pixels and scalar

This is the QVision processing block for the IPP function <b>ippiAbsDiff_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAbsDiff_sFloatC1Worker: public QVWorker
	{
	public:
		QVAbsDiff_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Squares pixel values of an image and places results in the destination image; for in-place flavors - in the same image

This is the QVision processing block for the IPP function <b>ippiSqr_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVSqr_sFloatC1Worker: public QVWorker
	{
	public:
		QVSqr_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the natural logarithm of each pixel values of a source image and places the results in the destination image; for in-place flavors - in the same image

This is the QVision processing block for the IPP function <b>ippiLn_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVLn_sFloatC1Worker: public QVWorker
	{
	public:
		QVLn_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the natural logarithm of each pixel values of a source image and places the results in the destination image; for in-place flavors - in the same image

This is the QVision processing block for the IPP function <b>ippiLn_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVLn_sFloatC3Worker: public QVWorker
	{
	public:
		QVLn_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiAndC_8u_C1R

This is the QVision processing block for the IPP function <b>ippiAndC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVAndC_uCharC1Worker: public QVWorker
	{
	public:
		QVAndC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Performs corresponding bitwise logical operation between pixels of two image (AndC OrC XorC - between pixel of the source image and a constant)

This is the QVision processing block for the IPP function <b>ippiNot_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVNot_uCharC1Worker: public QVWorker
	{
	public:
		QVNot_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Performs corresponding bitwise logical operation between pixels of two image (AndC OrC XorC - between pixel of the source image and a constant)

This is the QVision processing block for the IPP function <b>ippiNot_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVNot_uCharC3Worker: public QVWorker
	{
	public:
		QVNot_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiOrC_8u_C1R

This is the QVision processing block for the IPP function <b>ippiOrC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVOrC_uCharC1Worker: public QVWorker
	{
	public:
		QVOrC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiXorC_8u_C1R

This is the QVision processing block for the IPP function <b>ippiXorC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVXorC_uCharC1Worker: public QVWorker
	{
	public:
		QVXorC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiLShiftC_8u_C1R

This is the QVision processing block for the IPP function <b>ippiLShiftC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVLShiftC_uCharC1Worker: public QVWorker
	{
	public:
		QVLShiftC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiRShiftC_8u_C1R

This is the QVision processing block for the IPP function <b>ippiRShiftC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVRShiftC_uCharC1Worker: public QVWorker
	{
	public:
		QVRShiftC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Converts an RGB image to gray scale (fixed coefficients)

This is the QVision processing block for the IPP function <b>ippiRGBToGray_8u_C3C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVRGBToGray_uCharC3C1Worker: public QVWorker
	{
	public:
		QVRGBToGray_uCharC3C1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Converts an RGB image to gray scale (fixed coefficients)

This is the QVision processing block for the IPP function <b>ippiRGBToGray_32f_C3C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function

@ingroup qvippworkers
*/
class QVRGBToGray_sFloatC3C1Worker: public QVWorker
	{
	public:
		QVRGBToGray_sFloatC3C1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Performs thresholding of an image using the specified level

This is the QVision processing block for the IPP function <b>ippiThreshold_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param threshold	Corresponds to the same parameter of type IppiSize in the IPP function.
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVThreshold_uCharC1Worker: public QVWorker
	{
	public:
		QVThreshold_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Performs thresholding of an image using the specified level

This is the QVision processing block for the IPP function <b>ippiThreshold_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param threshold	Corresponds to the same parameter of type IppiSize in the IPP function.
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVThreshold_sFloatC1Worker: public QVWorker
	{
	public:
		QVThreshold_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Calculate Otsu theshold value of images

This is the QVision processing block for the IPP function <b>ippiComputeThreshold_Otsu_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pThreshold	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVComputeThreshold_Otsu_uCharC1Worker: public QVWorker
	{
	public:
		QVComputeThreshold_Otsu_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiCompare_8u_C1R

This is the QVision processing block for the IPP function <b>ippiCompare_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVCompare_uCharC1Worker: public QVWorker
	{
	public:
		QVCompare_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiCompare_32f_C1R

This is the QVision processing block for the IPP function <b>ippiCompare_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc1	Image corresponding to the data buffer pointer <i>pSrc1</i> and step number <i>src1Step</i> variables in the IPP function
@param qvimage_pSrc2	Image corresponding to the data buffer pointer <i>pSrc2</i> and step number <i>src2Step</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVCompare_sFloatC1Worker: public QVWorker
	{
	public:
		QVCompare_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Compares pixel values of two images, or pixel values of an image to a constant value using the following compare conditions

This is the QVision processing block for the IPP function <b>ippiCompareC_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVCompareC_uCharC1Worker: public QVWorker
	{
	public:
		QVCompareC_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Compares pixel values of two images, or pixel values of an image to a constant value using the following compare conditions

This is the QVision processing block for the IPP function <b>ippiCompareC_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param value	Corresponds to the same parameter of type IppiSize in the IPP function.
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param ippCmpOp	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVCompareC_sFloatC1Worker: public QVWorker
	{
	public:
		QVCompareC_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterBox_8u_C1R

This is the QVision processing block for the IPP function <b>ippiFilterBox_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterBox_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterBox_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterBox_8u_C3R

This is the QVision processing block for the IPP function <b>ippiFilterBox_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterBox_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterBox_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterBox_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterBox_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterBox_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterBox_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "min" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMin_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMin_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterMin_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "min" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMin_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMin_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterMin_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "min" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMin_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMin_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterMin_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "max" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMax_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMax_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterMax_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "max" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMax_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMax_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterMax_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Applies the "max" filter to an image

This is the QVision processing block for the IPP function <b>ippiFilterMax_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMax_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterMax_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Filters an image using a box median filter

This is the QVision processing block for the IPP function <b>ippiFilterMedian_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMedian_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterMedian_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Filters an image using a box median filter

This is the QVision processing block for the IPP function <b>ippiFilterMedian_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param maskSize	Corresponds to the same parameter of type IppiSize in the IPP function.
@param anchor	Corresponds to the same parameter of type IppiPoint in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMedian_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterMedian_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Performs horizontal median filtering

This is the QVision processing block for the IPP function <b>ippiFilterMedianHoriz_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterMedianHoriz_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterMedianHoriz_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterSobelHorizMask_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterSobelHorizMask_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterSobelHorizMask_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterSobelHorizMask_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterSobelVertMask_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterSobelVertMask_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterSobelVertMask_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterSobelVertMask_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterLaplace_8u_C1R

This is the QVision processing block for the IPP function <b>ippiFilterLaplace_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterLaplace_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterLaplace_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterLaplace_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterLaplace_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterLaplace_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterLaplace_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterGauss_8u_C1R

This is the QVision processing block for the IPP function <b>ippiFilterGauss_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterGauss_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterGauss_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterGauss_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterGauss_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterGauss_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterGauss_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterGauss_8u_C3R

This is the QVision processing block for the IPP function <b>ippiFilterGauss_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterGauss_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterGauss_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterGauss_32f_C3R

This is the QVision processing block for the IPP function <b>ippiFilterGauss_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterGauss_sFloatC3Worker: public QVWorker
	{
	public:
		QVFilterGauss_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterHipass_8u_C1R

This is the QVision processing block for the IPP function <b>ippiFilterHipass_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterHipass_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterHipass_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterHipass_8u_C3R

This is the QVision processing block for the IPP function <b>ippiFilterHipass_8u_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterHipass_uCharC3Worker: public QVWorker
	{
	public:
		QVFilterHipass_uCharC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterHipass_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterHipass_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterHipass_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterHipass_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterHipass_32f_C3R

This is the QVision processing block for the IPP function <b>ippiFilterHipass_32f_C3R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterHipass_sFloatC3Worker: public QVWorker
	{
	public:
		QVFilterHipass_sFloatC3Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterLowpass_8u_C1R

This is the QVision processing block for the IPP function <b>ippiFilterLowpass_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterLowpass_uCharC1Worker: public QVWorker
	{
	public:
		QVFilterLowpass_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief QVision wrapper function for IPP's ippiFilterLowpass_32f_C1R

This is the QVision processing block for the IPP function <b>ippiFilterLowpass_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param qvimage_pDst	Image corresponding to the data buffer pointer <i>pDst</i> and step number <i>dstStep</i> variables in the IPP function
@param mask	Corresponds to the same parameter of type IppiSize in the IPP function.

@ingroup qvippworkers
*/
class QVFilterLowpass_sFloatC1Worker: public QVWorker
	{
	public:
		QVFilterLowpass_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the sum of image pixel values

This is the QVision processing block for the IPP function <b>ippiSum_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pSum	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVSum_uCharC1Worker: public QVWorker
	{
	public:
		QVSum_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the mean of image pixel values

This is the QVision processing block for the IPP function <b>ippiMean_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pMean	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVMean_uCharC1Worker: public QVWorker
	{
	public:
		QVMean_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the minimum of image pixel values

This is the QVision processing block for the IPP function <b>ippiMin_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pMin	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVMin_uCharC1Worker: public QVWorker
	{
	public:
		QVMin_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the minimum of image pixel values

This is the QVision processing block for the IPP function <b>ippiMin_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pMin	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVMin_sFloatC1Worker: public QVWorker
	{
	public:
		QVMin_sFloatC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the maximum of image pixel values

This is the QVision processing block for the IPP function <b>ippiMax_8u_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pMax	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVMax_uCharC1Worker: public QVWorker
	{
	public:
		QVMax_uCharC1Worker(QString name = QString());
		void iterate();
	};

/*!
@brief Computes the maximum of image pixel values

This is the QVision processing block for the IPP function <b>ippiMax_32f_C1R</b>.
See <a href="http://www.intel.com/cd/software/products/asmo-na/eng/346532.htm">Intel's IPP documentation</a> for a deeper understanding of that function.
The properties of this data-processing block and the original IPP function corresponds as follows:
@param qvimage_pSrc	Image corresponding to the data buffer pointer <i>pSrc</i> and step number <i>srcStep</i> variables in the IPP function
@param pMax	Corresponds to the same parameter in the IPP function.

@ingroup qvippworkers
*/
class QVMax_sFloatC1Worker: public QVWorker
	{
	public:
		QVMax_sFloatC1Worker(QString name = QString());
		void iterate();
	};

#endif
